import time
import os
import re

import zhinst.ziPython
import zhinst.utils

def run_example(port=None, api_level=None, path=None):
    """
    Connect to a Zurich Instruments instrument, save the instrument's settings
    to file, toggle the signal output enable and reload the settings file.
    """

    # open a connection to a Zurich Instruments Server
    daq = zhinst.utils.autoConnect(port, api_level)
    # note: to specify directly which server you connect to please use the
    # following with port=8005 for HF2 and port=8004 for UHF:
    # daq = ziDAQServer('localhost',port)

    # detect device
    device = zhinst.utils.autoDetect(daq)

    timestr = time.strftime("%Y%m%d_%H%M")
    filename_noext = timestr + '_settings' # Change this to the filename you want to save.

    timeout = 500 # [ms]
    h = daq.deviceSettings(timeout);
    h.set('devicesettings/device', device)
    h.set('devicesettings/filename', filename_noext)
    if path:
        h.set('devicesettings/path', path)
    # set the path to '.' save to the current directory Note: this
    # example/m-file will have to copied to a folder where you have write
    # access.
    # h.set('devicesettings/path', '.')

    toggleDeviceSetting(daq, device)
    
    # Save settings
    print "Saving settings..."
    h.set('devicesettings/command', 'save')
    h.execute()
    while not h.finished():
      time.sleep(0.2)
    print "Done."

    data = h.get('devicesettings/path')
    path = data['path'][0]
    filename_full_path = os.path.join(path, filename_noext) + '.xml'
    assert os.path.isfile(filename_full_path), "Failed to save settings file '%s'" % filename_full_path
    print "Saved file '%s'." % filename_full_path

    toggleDeviceSetting(daq, device)
    
    # Load settings
    print "Loading settings..."
    h.set('devicesettings/command', 'load')
    h.execute()
    while not h.finished():
      time.sleep(0.2)
    print "Done."

def toggleDeviceSetting(daq, device):
    path = '/%s/sigouts/0/on' %(device)
    on = daq.getInt(path)
    on = not on
    print "Toggling '%s'." % path
    daq.syncSetInt(path, on)

if __name__ == '__main__':
    run_example()
